Screen

Struct Screen 

pub struct Screen { /* private fields */ }
Represents the overall terminal state.

Implementations

Source

impl Screen

pub fn set_size(&mut self, rows: u16, cols: u16)

Resizes the terminal.

pub fn size(&self) -> (u16, u16)

Returns the current size of the terminal.

The return value will be (rows, cols).

pub fn scrollback_len(&self) -> usize

Returns the number of lines in the scrollback.

pub fn set_scrollback(&mut self, rows: usize)

Scrolls to the given position in the scrollback.

This position indicates the offset from the top of the screen, and should be 0 to put the normal screen in view.

This affects the return values of methods called on the screen: for instance, screen.cell(0, 0) will return the top left corner of the screen after taking the scrollback offset into account.

The value given will be clamped to the actual size of the scrollback.

pub fn scrollback(&self) -> usize

Returns the current position in the scrollback.

This position indicates the offset from the top of the screen, and is 0 when the normal screen is in view.

pub fn contents(&self) -> String

Returns the text contents of the terminal.

This will not include any formatting information, and will be in plain text format.

pub fn rows(&self, start: u16, width: u16) -> impl Iterator<Item = String> + '_

Returns the text contents of the terminal by row, restricted to the given subset of columns.

This will not include any formatting information, and will be in plain text format.

Newlines will not be included.

pub fn contents_between( &self, start_row: u16, start_col: u16, end_row: u16, end_col: u16, ) -> String

Returns the text contents of the terminal logically between two cells. This will include the remainder of the starting row after start_col, followed by the entire contents of the rows between start_row and end_row, followed by the beginning of the end_row up until end_col. This is useful for things like determining the contents of a clipboard selection.

pub fn state_formatted(&self) -> Vec<u8>

Return escape codes sufficient to reproduce the entire contents of the current terminal state. This is a convenience wrapper around contents_formatted and input_mode_formatted.

pub fn state_diff(&self, prev: &Self) -> Vec<u8>

Return escape codes sufficient to turn the terminal state of the screen prev into the current terminal state. This is a convenience wrapper around contents_diff and input_mode_diff.

pub fn contents_formatted(&self) -> Vec<u8>

Returns the formatted visible contents of the terminal.

Formatting information will be included inline as terminal escape codes. The result will be suitable for feeding directly to a raw terminal parser, and will result in the same visual output.

pub fn rows_formatted( &self, start: u16, width: u16, ) -> impl Iterator<Item = Vec<u8>> + '_

Returns the formatted visible contents of the terminal by row, restricted to the given subset of columns.

Formatting information will be included inline as terminal escape codes. The result will be suitable for feeding directly to a raw terminal parser, and will result in the same visual output.

You are responsible for positioning the cursor before printing each row, and the final cursor position after displaying each row is unspecified.

pub fn contents_diff(&self, prev: &Self) -> Vec<u8>

Returns a terminal byte stream sufficient to turn the visible contents of the screen described by prev into the visible contents of the screen described by self.

The result of rendering prev.contents_formatted() followed by self.contents_diff(prev) should be equivalent to the result of rendering self.contents_formatted(). This is primarily useful when you already have a terminal parser whose state is described by prev, since the diff will likely require less memory and cause less flickering than redrawing the entire screen contents.

pub fn rows_diff<'a>( &'a self, prev: &'a Self, start: u16, width: u16, ) -> impl Iterator<Item = Vec<u8>> + 'a

Returns a sequence of terminal byte streams sufficient to turn the visible contents of the subset of each row from prev (as described by start and width) into the visible contents of the corresponding row subset in self.

You are responsible for positioning the cursor before printing each row, and the final cursor position after displaying each row is unspecified.

pub fn input_mode_formatted(&self) -> Vec<u8>

Returns terminal escape sequences sufficient to set the current terminal’s input modes.

Supported modes are:

  • application keypad
  • application cursor
  • bracketed paste
  • xterm mouse support
pub fn input_mode_diff(&self, prev: &Self) -> Vec<u8>

Returns terminal escape sequences sufficient to change the previous terminal’s input modes to the input modes enabled in the current terminal.

pub fn attributes_formatted(&self) -> Vec<u8>

Returns terminal escape sequences sufficient to set the current terminal’s drawing attributes.

Supported drawing attributes are:

  • fgcolor
  • bgcolor
  • bold
  • dim
  • italic
  • underline
  • inverse

This is not typically necessary, since contents_formatted will leave the current active drawing attributes in the correct state, but this can be useful in the case of drawing additional things on top of a terminal output, since you will need to restore the terminal state without the terminal contents necessarily being the same.

pub fn cursor_position(&self) -> (u16, u16)

Returns the current cursor position of the terminal.

The return value will be (row, col).

pub fn cursor_state_formatted(&self) -> Vec<u8>

Returns terminal escape sequences sufficient to set the current cursor state of the terminal.

This is not typically necessary, since contents_formatted will leave the cursor in the correct state, but this can be useful in the case of drawing additional things on top of a terminal output, since you will need to restore the terminal state without the terminal contents necessarily being the same.

Note that the bytes returned by this function may alter the active drawing attributes, because it may require redrawing existing cells in order to position the cursor correctly (for instance, in the case where the cursor is past the end of a row). Therefore, you should ensure to reset the active drawing attributes if necessary after processing this data, for instance by using attributes_formatted.

pub fn cell(&self, row: u16, col: u16) -> Option<&Cell>

Returns the Cell object at the given location in the terminal, if it exists.

pub fn row_wrapped(&self, row: u16) -> bool

Returns whether the text in row row should wrap to the next line.

pub fn alternate_screen(&self) -> bool

Returns whether the alternate screen is currently in use.

pub fn application_keypad(&self) -> bool

Returns whether the terminal should be in application keypad mode.

pub fn application_cursor(&self) -> bool

Returns whether the terminal should be in application cursor mode.

pub fn hide_cursor(&self) -> bool

Returns whether the terminal should be in hide cursor mode.

pub fn bracketed_paste(&self) -> bool

Returns whether the terminal should be in bracketed paste mode.

pub fn mouse_protocol_mode(&self) -> MouseProtocolMode

Returns the currently active MouseProtocolMode.

pub fn mouse_protocol_encoding(&self) -> MouseProtocolEncoding

Returns the currently active MouseProtocolEncoding.

pub fn fgcolor(&self) -> Color

Returns the currently active foreground color.

pub fn bgcolor(&self) -> Color

Returns the currently active background color.

pub fn bold(&self) -> bool

Returns whether newly drawn text should be rendered with the bold text attribute.

pub fn dim(&self) -> bool

Returns whether newly drawn text should be rendered with the dim text attribute.

pub fn italic(&self) -> bool

Returns whether newly drawn text should be rendered with the italic text attribute.

pub fn underline(&self) -> bool

Returns whether newly drawn text should be rendered with the underlined text attribute.

pub fn inverse(&self) -> bool

Returns whether newly drawn text should be rendered with the inverse text attribute.