Enum vt100::MouseProtocolMode[][src]

pub enum MouseProtocolMode {
    None,
    Press,
    PressRelease,
    ButtonMotion,
    AnyMotion,
}
The xterm mouse handling mode currently in use.

Variants

None

Mouse handling is disabled.

Press

Mouse button events should be reported on button press. Also known as X10 mouse mode.

PressRelease

Mouse button events should be reported on button press and release. Also known as VT200 mouse mode.

ButtonMotion

Mouse button events should be reported on button press and release, as well as when the mouse moves between cells while a button is held down.

AnyMotion

Mouse button events should be reported on button press and release, and mouse motion events should be reported when the mouse moves between cells regardless of whether a button is held down or not.