pub struct Parser<CB: Callbacks = ()> { /* private fields */ }Expand description
A parser for terminal output which produces an in-memory representation of the terminal contents.
Implementations
Sourceimpl<CB: Callbacks> Parser<CB>
impl<CB: Callbacks> Parser<CB>
Sourcepub fn new_with_callbacks(
rows: u16,
cols: u16,
scrollback_len: usize,
callbacks: CB,
) -> Self
pub fn new_with_callbacks( rows: u16, cols: u16, scrollback_len: usize, callbacks: CB, ) -> Self
Creates a new terminal parser of the given size and with the given
amount of scrollback. Terminal events will be reported via method
calls on the provided Callbacks
implementation.
Sourcepub fn process(&mut self, bytes: &[u8])
pub fn process(&mut self, bytes: &[u8])
Processes the contents of the given byte string, and updates the in-memory terminal state.
Sourcepub fn screen(&self) -> &Screen
pub fn screen(&self) -> &Screen
Returns a reference to a Screen object containing
the terminal state.
Sourcepub fn screen_mut(&mut self) -> &mut Screen
pub fn screen_mut(&mut self) -> &mut Screen
Returns a mutable reference to a Screen object
containing the terminal state.
Sourcepub fn callbacks(&self) -> &CB
pub fn callbacks(&self) -> &CB
Returns a reference to the Callbacks
state object passed into the constructor.
Sourcepub fn callbacks_mut(&mut self) -> &mut CB
pub fn callbacks_mut(&mut self) -> &mut CB
Returns a mutable reference to the
Callbacks state object passed into
the constructor.