Trait Callbacks

pub trait Callbacks {
    // Provided methods
    fn audible_bell(&mut self, _: &mut Screen) { ... }
    fn visual_bell(&mut self, _: &mut Screen) { ... }
    fn resize(&mut self, _: &mut Screen, _request: (u16, u16)) { ... }
    fn set_window_icon_name(&mut self, _: &mut Screen, _icon_name: &[u8]) { ... }
    fn set_window_title(&mut self, _: &mut Screen, _title: &[u8]) { ... }
    fn copy_to_clipboard(&mut self, _: &mut Screen, _ty: &[u8], _data: &[u8]) { ... }
    fn paste_from_clipboard(&mut self, _: &mut Screen, _ty: &[u8]) { ... }
    fn unhandled_char(&mut self, _: &mut Screen, _c: char) { ... }
    fn unhandled_control(&mut self, _: &mut Screen, _b: u8) { ... }
    fn unhandled_escape(
        &mut self,
        _: &mut Screen,
        _i1: Option<u8>,
        _i2: Option<u8>,
        _b: u8,
    ) { ... }
    fn unhandled_csi(
        &mut self,
        _: &mut Screen,
        _i1: Option<u8>,
        _i2: Option<u8>,
        _params: &[&[u16]],
        _c: char,
    ) { ... }
    fn unhandled_osc(&mut self, _: &mut Screen, _params: &[&[u8]]) { ... }
}
This trait is used by the parser to handle extra escape sequences that don’t have an impact on the terminal screen directly.

Provided Methods

fn audible_bell(&mut self, _: &mut Screen)

This callback is called when the terminal requests an audible bell (typically with ^G).

fn visual_bell(&mut self, _: &mut Screen)

This callback is called when the terminal requests a visual bell (typically with \eg).

fn resize(&mut self, _: &mut Screen, _request: (u16, u16))

This callback is called when the terminal requests a resize (typically with \e[8;<rows>;<cols>t).

fn set_window_icon_name(&mut self, _: &mut Screen, _icon_name: &[u8])

This callback is called when the terminal requests the window title to be set (typically with \e]1;<icon_name>\a)

fn set_window_title(&mut self, _: &mut Screen, _title: &[u8])

This callback is called when the terminal requests the window title to be set (typically with \e]2;<title>\a)

fn copy_to_clipboard(&mut self, _: &mut Screen, _ty: &[u8], _data: &[u8])

This callback is called when the terminal requests data to be copied to the system clipboard (typically with \e]52;<ty>;<data>\a). Note that data will be encoded as base64.

fn paste_from_clipboard(&mut self, _: &mut Screen, _ty: &[u8])

This callback is called when the terminal requests data to be pasted from the system clipboard (typically with \e]52;<ty>;?\a).

fn unhandled_char(&mut self, _: &mut Screen, _c: char)

This callback is called when the terminal receives an escape sequence which is otherwise not implemented.

fn unhandled_control(&mut self, _: &mut Screen, _b: u8)

This callback is called when the terminal receives a control character which is otherwise not implemented.

fn unhandled_escape( &mut self, _: &mut Screen, _i1: Option<u8>, _i2: Option<u8>, _b: u8, )

This callback is called when the terminal receives an escape sequence which is otherwise not implemented.

fn unhandled_csi( &mut self, _: &mut Screen, _i1: Option<u8>, _i2: Option<u8>, _params: &[&[u16]], _c: char, )

This callback is called when the terminal receives a CSI sequence (\e[) which is otherwise not implemented.

fn unhandled_osc(&mut self, _: &mut Screen, _params: &[&[u8]])

This callback is called when the terminal receives a OSC sequence (\e]) which is otherwise not implemented.

Implementations on Foreign Types

Source

impl Callbacks for ()

Implementors